@@ -24,11 +24,13 @@
 
 #include <string.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <ctype.h>
 #include <errno.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <glib-object.h>
+#include <signal.h>
 #include <sys/wait.h> /* waitpid */
 #include <gmodule.h>
 #include "scanner.h"
@@ -1580,7 +1582,7 @@ g_igenerator_start_preprocessor (GIGenerator *igenerator,
   tmp = g_file_open_tmp (NULL, &tmpname, &error);
   if (error != NULL)
     {
-      g_error (error->message);
+      g_error ("%s", error->message);
       return NULL;
     }
 
@@ -1615,7 +1617,7 @@ g_igenerator_start_preprocessor (GIGenerator *igenerator,
   f = fdopen (tmp, "r");
   if (!f)
     {
-      g_error (strerror (errno));
+      g_error ("%s", strerror (errno));
       unlink (tmpname);
       g_free (tmpname);
       return NULL;
